function [partE, labeling, frSegment, affPotential] = calcLabeling(searchImage, frSegment, models, neighbors, colorPotential, foreRatio, backRatio, frame, iter)

global opts

%% load models
curSegment = frSegment{opts.lenSegment};
targetProposalModel = models.targetProposalModel;
targetStructModel = models.targetStructModel;

nNodes = size(curSegment.spFeature.spSearchFeature,1);
nLabels = models.targetStructModel.numParts + 1;

%% calculate the cost of target proposal
[targetProposalCost, Scost, foreScore] = calcTargetProposalCost(curSegment, targetProposalModel, nNodes, nLabels);
targetData = calcTargetData(foreRatio, backRatio, nNodes, nLabels);
targetProposalCost = targetProposalCost + targetData;

%% calculate the cost of target structure
[affPotential, structPotential] = calcTargetStructureCost(curSegment, targetStructModel, nNodes, nLabels);

%% obtain labeling by graph-cut
[partE, labeling] = graphcutLabeling(targetProposalCost, affPotential, colorPotential, structPotential, Scost, neighbors);

%% update the frame segment
curSegment.foreNodes = find(labeling~=1);
curSegment.foreVal = nnz(labeling~=1);
curSegment.spConf = foreScore;
frSegment{opts.lenSegment} = curSegment;

%% occlusion?
sumForeVal = 0;
for i = 1:opts.lenSegment
    sumForeVal = sumForeVal + frSegment{opts.lenSegment}.foreVal;
end
if(frSegment{opts.lenSegment}.foreVal >= sumForeVal/opts.lenSegment*0.65)
    opts.flagOcc = false;
else
    opts.flagOcc = true;
end

%% show candidate parts
% showCandidateParts(searchImage, curSegment.spLabels.searchSpLabel, curSegment.foreNodes, labeling, frame, iter);