function [segLabel, spConf] = initTargetParts(searchImage, spLabels, spFeature, targetProposalModel)

global opts

spSearchPos = spFeature.spSearchPos;
nodesFeat = spFeature.spSearchFeature;
spLabel = spLabels.searchSpLabel;
colorBins = spLabels.c_bins;

%% calculate the data term
nNodes = size(spSearchPos, 1);
% generative cost
genData = zeros(2, nNodes);
for i = 1:nNodes
    idx = spLabel == i;    
    genData(1,i) = mean(-log(targetProposalModel.genModel.backModel(colorBins(idx))));   
    genData(2,i) = mean(-log(targetProposalModel.genModel.foreModel(colorBins(idx))));
end
% discriminative cost
disData = zeros(2, nNodes);
btrain = targetProposalModel.disModel(end);
wtrain = targetProposalModel.disModel(1:end-1);
decision_values = wtrain'*nodesFeat' + btrain;
% spConf = 1./(1+exp(-decision_values*5));

spConf = (decision_values + (genData(1,:)-genData(2,:)))/2;
spConf = 1./(1+exp(-spConf));

idx = decision_values >=0;
disData(1,idx) = decision_values(idx)*15;
disData(2,idx) = -decision_values(idx)*15;
disData(1,~idx) = decision_values(~idx);
disData(2,~idx) = -decision_values(~idx);
% data cost
Data_term = opts.segGenWeight*genData + opts.segDisWeight*disData;

%% calculate the smooth term
Smooth_term = ones(2, 2);
Smooth_term = Smooth_term - diag(diag(Smooth_term));

%% build the neighbor connections
search_radius = sqrt(nnz(spLabel)/nNodes);
neighbors = pdist2(spSearchPos, spSearchPos, 'euclidean');
neighbors = (neighbors <= 1.5*search_radius & neighbors > 0);
neighbors = triu(neighbors,1);
% calculate color smoothness
% searchImage = rgb2hsi(searchImage);
colorFeat = zeros(nNodes, 3);
for k = 1:nNodes
    idx = spLabel == k;
    for i = 1:3
        temp = searchImage(:,:, i);
        colorFeat(k,i) = mean(temp(idx));
    end
end
% colorPotential = zeros(nNodes);
% for i = 1:nNodes
%     for j = 1:nNodes
%         if(neighbors(i,j))
%             colorPotential(i,j) = exp(-calcX2Dist(nodesFeat(i,:), nodesFeat(j,:)));
%         end
%     end
% end
colorPotential = exp(-pdist2(colorFeat, colorFeat)*0.05);
neighbors = opts.smoothWeight*neighbors.*colorPotential;    

% compute optimal labeling via graph cut
gch = GraphCut('open', Data_term, Smooth_term, sparse(neighbors));
[gch, segLabel] = GraphCut('expand',gch);
GraphCut('close', gch);
segLabel = segLabel' ~= 0;