function [targetProposalModel, spLabels, spFeature, posLabel] = initTargetPropoalModel(targetState, searchImage, searchPos, targetAppModel)

global opts

targetSize = targetState.targetSize;

% over-segmentation of image and calculation of attributes
[spLabels, spFeature] = calcSuperpixel(searchImage, searchPos);
spLabel = spLabels.searchSpLabel;

% Get background (frame around target) and foreground masks (inner portion of target)
pad_offset1 = (targetAppModel.bg_area-targetSize)/2; % we constrained the difference to be mod2, so we do not have to round here
assert(sum(pad_offset1==round(pad_offset1))==2, 'difference between background area and target size has to be even.');

backMask = true(targetAppModel.bg_area); % init background mask
pad_offset1(pad_offset1<=0)=1;
backMask(pad_offset1(1)+1:end-pad_offset1(1), pad_offset1(2)+1:end-pad_offset1(2)) = false;

pad_offset2 = (targetAppModel.bg_area-targetAppModel.fg_area)/2; % we constrained the difference to be mod2, so we do not have to round here
assert(sum(pad_offset2==round(pad_offset2))==2, 'difference between background area and foreground area has to be even.');
foreMask = false(targetAppModel.bg_area); % init foreground mask
pad_offset2(pad_offset2<=0)=1;
foreMask(pad_offset2(1)+1:end-pad_offset2(1), pad_offset2(2)+1:end-pad_offset2(2)) = true;

foreMask = imresize(foreMask, targetAppModel.norm_bg_area);
backMask = imresize(backMask, targetAppModel.norm_bg_area);
foreMask = double(foreMask).*spLabel;
backMask = double(backMask).*spLabel;

numSuperpixel = numel(unique(spLabel));
spArea = zeros(1, numSuperpixel);
foreArea = zeros(1, numSuperpixel);
backArea = zeros(1, numSuperpixel);
for k = 1:numSuperpixel
    spArea(k) = sum(sum(spLabel == k));
    foreArea(k) = sum(sum(foreMask == k));
    backArea(k) = sum(sum(backMask == k));    
end
posLabel = foreArea > opts.threTrainRatio*spArea;
negLabel = backArea > opts.threTrainRatio*spArea;
if(~nnz(posLabel))
    posLabel = ~negLabel;
end
% calculate the discriminative model
foreFeat = spFeature.spSearchFeature(posLabel, :);
backFeat = spFeature.spSearchFeature(negLabel, :);
opts.foreFeat = spFeature.spSearchFeature(posLabel, :);
opts.backFeat = spFeature.spSearchFeature(negLabel, :);
targetProposalModel.disModel = calcDisModel(foreFeat, backFeat);
% calculate the generative model
targetProposalModel.genModel = initGenModels(searchImage, spLabels.searchSpLabel, posLabel, negLabel);