function [frSegment, fitModels, foreRatio, backRatio, extraNodes] = refitModels(imgdat, searchPos, targetState, labeling, frSegment, models, affPotential, preModels, oldE, frame)

global opts

targetCenter = targetState.targetCenter;
targetSize = targetState.targetSize;

newModels = models;
targetAppModel = newModels.targetAppModel;
targetProposalModel = newModels.targetProposalModel;

searchFeat = frSegment{opts.lenSegment}.spFeature.spSearchFeature;
spLabels = frSegment{opts.lenSegment}.spLabels;
c_bins = spLabels.c_bins;
spLabel = spLabels.searchSpLabel;

%% refit the target proposal model
[posLabel, negLabel, foreRatio, backRatio] = findForeSample(imgdat, spLabel, targetCenter, targetSize, targetAppModel.bg_area, searchPos, targetAppModel.norm_target_sz);
candidateNodes = find(posLabel);
posLabel = intersect(candidateNodes, frSegment{opts.lenSegment}.foreNodes);
if(~opts.flagOcc && numel(posLabel))
    mixForeFeat = [];
    mixBackFeat = [];
    targetProposalModel.genModel.foreModel = zeros(size(targetProposalModel.genModel.foreModel));
    targetProposalModel.genModel.backModel = zeros(size(targetProposalModel.genModel.backModel));
    mixForeFeat = cat(1, mixForeFeat, searchFeat(posLabel, :));  
    % combine the negtive searching samples
    negLabel = find(negLabel);
    [~, idx] = sort(frSegment{opts.lenSegment}.spConf(negLabel),'descend'); % mine hard negative samples
    idx = idx(1:min(numel(posLabel),numel(negLabel)));
    negLabel = negLabel(idx); 
    mixBackFeat = cat(1, mixBackFeat, searchFeat(negLabel, :));        
    % update the generative model
    targetProposalModel.genModel.foreModel = updateGenModel(c_bins, spLabel, posLabel);
    targetProposalModel.genModel.backModel = updateGenModel(c_bins, spLabel, negLabel);
    % combine the initial samples
    mixForeFeat = cat(1, mixForeFeat, opts.foreFeat);
    mixBackFeat = cat(1, mixBackFeat, opts.backFeat);
    % update the discriminative model
    newModels.targetProposalModel.disModel = calcDisModel(mixForeFeat, mixBackFeat);
    % normalization of the histogram 
    targetProposalModel.genModel.foreModel = 0.7*targetProposalModel.genModel.foreModel + 0.3*opts.initForeModel;
    targetProposalModel.genModel.foreModel = targetProposalModel.genModel.foreModel/sum(targetProposalModel.genModel.foreModel);   
    targetProposalModel.genModel.backModel = 0.7*targetProposalModel.genModel.backModel + 0.3*opts.initBackModel;    
    targetProposalModel.genModel.backModel = targetProposalModel.genModel.backModel/sum(targetProposalModel.genModel.backModel); 
    targetProposalModel.genModel.foreModel(targetProposalModel.genModel.foreModel==0) = min(0.0001, min(targetProposalModel.genModel.foreModel(targetProposalModel.genModel.foreModel>0))/2);
    targetProposalModel.genModel.backModel(targetProposalModel.genModel.backModel==0) = min(0.0001, min(targetProposalModel.genModel.backModel(targetProposalModel.genModel.backModel>0))/2);    
    newModels.targetProposalModel.genModel = targetProposalModel.genModel;
    % calculate new datacost
    [Dcost, spConf] = calcDatacost(frSegment{opts.lenSegment}, targetProposalModel, affPotential);
    newE = calcLabelingEnergy(Dcost, labeling);
    if(newE < oldE)   
        fitModels = newModels;
        frSegment{opts.lenSegment}.spConf = spConf;
    else
        fitModels = models;
    end
else
    fitModels = models; 
end
extraNodes = setdiff(candidateNodes, posLabel);

%% refit the target structure model
models_ = fitModels;
matchLabel = setdiff(unique(labeling), 1);
votePos = targetCenter([2 1]) - searchPos(1:2);
frSegment{opts.lenSegment}.spFeature.spSearchSeed = repmat(votePos, [numel(unique(spLabel)), 1]) + frSegment{opts.lenSegment}.spFeature.spSearchOffset;

if(~opts.flagOcc) 
    for i = 1:numel(matchLabel)
        canPartId = find(labeling == matchLabel(i));
        graphPartId = matchLabel(i) - 1;
        xDiff = mean(frSegment{opts.lenSegment}.spFeature.spSearchOffset(canPartId, 1)) - models_.targetStructModel.partVector(graphPartId, 1);
        yDiff = mean(frSegment{opts.lenSegment}.spFeature.spSearchOffset(canPartId, 2)) - models_.targetStructModel.partVector(graphPartId, 2);
        offsetDist = sqrt(xDiff*xDiff + yDiff*yDiff);    
        if(offsetDist <= 1.5*opts.spSize)
            models_.targetStructModel.numFrPartTrack(graphPartId) = frame;    
            models_.targetStructModel.partPos(graphPartId,:) = mean(frSegment{opts.lenSegment}.spFeature.spSearchSeed(canPartId,:));    
            models_.targetStructModel.partVector(graphPartId,:) = mean(frSegment{opts.lenSegment}.spFeature.spSearchOffset(canPartId,:));    
            models_.targetStructModel.partFeat(graphPartId,:) = mean(frSegment{opts.lenSegment}.spFeature.spSearchFeature(canPartId,:));           
            models_.targetStructModel.partConf(graphPartId) = mean(frSegment{opts.lenSegment}.spConf(canPartId));               
        end
    end
end

%% refit the target appearance model
fitModels = models_;
fitModels.targetAppModel = updateTargetAppModel(imgdat, targetState, preModels.targetAppModel);