function [spModels, spCandidate] = updateStructModel(imgdat, targetCenter, targetSize, spModels, spCandidate, searchPos, frame)

global opts

spLabel = spCandidate{opts.frameBuffer}.spLabels.searchSpLabel;
[posLabel, negLabel] = findForeSample(imgdat, spLabel, targetCenter, targetSize, spModels.bg_area, searchPos);
spCandidate{opts.frameBuffer}.prob(negLabel) = -inf;
candidateNodes = find(posLabel);

% update the position of target parts
votePos = targetCenter([2 1]) - searchPos;
spCandidate{opts.frameBuffer}.spFeature.spSearchSeed = repmat(votePos, [numel(unique(spLabel)), 1]) + spCandidate{opts.frameBuffer}.spFeature.spSearchOffset;
% %% update target structure
structModel = spModels.structModel;
spStructure = spCandidate{opts.frameBuffer};
partLabel = spStructure.partLabel;
canParts = find(partLabel~=0);

structModel.numFrSpTrack(setdiff(unique(partLabel),0)) = frame;
if(opts.flagOcc) 
    %% graph parts updating
    for i = 1:numel(canParts)
        canPartId = canParts(i);
        graphPartId = partLabel(canPartId);

        xDiff = spStructure.spFeature.spSearchOffset(canPartId, 1) - structModel.spVector(graphPartId, 1);
        yDiff = spStructure.spFeature.spSearchOffset(canPartId, 2) - structModel.spVector(graphPartId, 2);
        offsetDist = sqrt(xDiff*xDiff + yDiff*yDiff);    
        if(offsetDist < 1.5*opts.spSize)
            structModel.numFrSpTrack(graphPartId) = frame;    
            structModel.spRelPos(graphPartId,:) = spStructure.spFeature.spSearchSeed(canPartId,:);    
            structModel.spVector(graphPartId,:) = spStructure.spFeature.spSearchOffset(canPartId,:);    
            structModel.spFeat(graphPartId,:) = spStructure.spFeature.spSearchFeature(canPartId,:);   
        end
    end        

    %% graph parts death, if specific part hasn't been successfully matched for several frames
    dropList = zeros(numel(structModel.numFrSpTrack), 1);
    for i = 1:numel(structModel.numFrSpTrack)
        if(frame - structModel.numFrSpTrack(i) > opts.graphDeathFrame)
            dropList(i) = 1;
            % if the number of parts in graph is too small, do not delete old part
            if(numel(structModel.numFrSpTrack) - sum(dropList) <= 0.5*opts.numInitTargetParts)
                break;
            end
        end
    end
    structModel.numFrSpTrack = structModel.numFrSpTrack(~dropList);  
    structModel.spRelPos = structModel.spRelPos(~dropList,:);      
    structModel.spVector = structModel.spVector(~dropList,:);  
    structModel.spFeat = structModel.spFeat(~dropList,:);   
    
    %% graph parts birth
    extraNodes = setdiff(candidateNodes, canParts);
    for i = 1:numel(extraNodes)
        canPartId = extraNodes(i);
        % if the number of nodes in graph is too large, do not create new part
        if(numel(structModel.numFrSpTrack) < 2*opts.numInitTargetParts)
            flag = true;
            for k = 1:numel(structModel.numFrSpTrack)
                nodeDist = pdist2(spStructure.spFeature.spSearchSeed(canPartId, :), structModel.spRelPos(k, :));            
                if(nodeDist < 1.2*opts.spSize)
                    flag = false;
                    break;
                end
            end
            if(flag)
                structModel.numFrSpTrack = cat(2, structModel.numFrSpTrack, frame);
                structModel.spRelPos = cat(1, structModel.spRelPos, spStructure.spFeature.spSearchSeed(canPartId,:));                    
                structModel.spVector = cat(1, structModel.spVector, spStructure.spFeature.spSearchOffset(canPartId,:));    
                structModel.spFeat = cat(1, structModel.spFeat, spStructure.spFeature.spSearchFeature(canPartId,:));   
            end
        end
    end
else
    structModel.numFrSpTrack = structModel.numFrSpTrack + 1; % update the frame number of part tracking
end
structModel.nParts = length(structModel.numFrSpTrack);
spModels.structModel = structModel;