function imgdat = initParameters_VOT(image, region)

global opts gt trackingResults trackError overLap runTime iterEnergy

opts.debug = false; % print the variable information
opts.showTrackingResults = false; % show the tracking result
opts.showCandidateParts = false; % show the candidate target parts
opts.showResponseMap = false; % show the response map

%% load groundtruth path
gt = region;
numFrames = 2000;

%% load sequence path
imgdat = imread(image);
imgdat = gray2rgb(imgdat);

%% tracking results
opts.maxIters = 5;
opts.colorName = true;

trackingResults = zeros(numFrames, numel(region));   
iterEnergy = zeros(numFrames, opts.maxIters);
trackError = zeros(1, numFrames);
overLap = 100*ones(1, numFrames);
runTime = zeros(1, numFrames);

%% parameters for target appearance model
opts.hog_cell_size = 4;
opts.fixed_area = 150^2;           % standard area to which we resize the target
opts.inner_padding = 0.2;             % defines inner area used to sample colors from the foreground
opts.output_sigma_factor = 1/16 ;             % standard deviation for the desired translation filter output
opts.lambda = 1e-3;                                   % regularization weight
opts.learning_rate_cf = 0.01;            % HOG model learning rate
opts.hog_scale_cell_size = 4;            
opts.learning_rate_scale = 0.025;
opts.scale_sigma_factor = 1/4;
opts.num_scales = 33;
opts.scale_model_factor = 1.0;
opts.scale_step = 1.02;
opts.scale_model_max_area = 32*16;
temp = load('w2crs');
opts.w2c = temp.w2crs;

%% parameters for target proposal model
% scaling factors
opts.segGenWeight = 100; % weight for generative term
opts.segDisWeight = 100; % weight for discriminative term
opts.segAffWeight = 200; % weight for part potential term
opts.smoothWeight = 50; % weight for smooth term
opts.targetWeight = 200; % weight for target term
opts.appearanceAlpha = 1; % weight for the apperance similarity

% parameters for superpxiels
opts.minNumSuperpixels = 100;
opts.maxNumSuperpixels = round(150*150/125);
opts.nPixelInSuperpixel = 125;

% number of bins for HSV
opts.nHBins = 6; 
opts.nSBins = 6;
opts.nVBins = 6;

opts.typeFeat = 2; % 1:hsv 2:hsv+lbp
opts.svmC = 7; % C value for SVM

%% tracking parameters
opts.fusionWeight = 0.7; % the fusion weight of the target response
opts.posnegFactor = [0.5 0.1];
opts.lenSegment = 5; % the length of frame segment 
opts.graphDeathFrame = 5; % the frame number to keep the model
opts.threTrainRatio = 0.8; % determine the ratio of training samples
opts.partsColor = 255*rand(500, 3); % the color of target parts