function [E, labeling] = alphaExpansion(Dcost, Scost, Neighbor)
% minimize energy by alpha expansion
% 
% Copyright (C) David Do.
%
% The code may be used free of charge for non-commercial and
% educational purposes, the only requirement is that this text is
% preserved within the derivative work. For any other purpose you
% must contact the authors for permission. This code may not be
% redistributed without written permission from the authors.


% The gco code is available at
% http://vision.csd.uwo.ca/code/


% set up GCO structure
[nLabels, nPoints] = size(Dcost);

h = GCO_Create(nPoints,nLabels);
GCO_SetDataCost(h, int32(Dcost));

if ~isempty(Scost) && any(any(Scost))
    GCO_SetSmoothCost(h,int32(Scost));
    GCO_SetNeighbors(h, Neighbor);
end

GCO_Expansion(h);
labeling = GCO_GetLabeling(h)';
E = GCO_ComputeEnergy(h);
GCO_Delete(h);